@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,6 +25,8 @@
 #include "followupreminder_export.h"
 class KConfigGroup;
 namespace FollowUpReminder {
+
+/** Follow up reminder information. */
 class FOLLOWUPREMINDER_EXPORT FollowUpReminderInfo
 {
 public:
@@ -79,4 +81,5 @@ private:
     bool mAnswerWasReceived = false;
 };
 }
+FOLLOWUPREMINDER_EXPORT QDebug operator<<(QDebug debug, const FollowUpReminder::FollowUpReminderInfo &info);
 #endif // FOLLOWUPREMINDERINFO_H
