@@ -25,6 +25,8 @@
 
 namespace SendLater {
 class SendLaterInfo;
+
+/** Send later utilities. */
 namespace SendLaterUtil {
 Q_REQUIRED_RESULT SENDLATER_EXPORT bool compareSendLaterInfo(SendLater::SendLaterInfo *left, SendLater::SendLaterInfo *right);
 
@@ -42,6 +44,7 @@ SENDLATER_EXPORT void changeRecurrentDate(SendLater::SendLaterInfo *info);
 SENDLATER_EXPORT void forceReparseConfiguration();
 
 Q_REQUIRED_RESULT SENDLATER_EXPORT QString sendLaterPattern();
+SENDLATER_EXPORT void removeItem(qint64 item);
 }
 }
 #endif // SENDLATERUTIL_H
